import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { AgeVerificationCmsService } from "./age-verification-cms.service";
import { UpdateAgeVerificationCmsDto } from "./dto/update-age-verification-cms.dto";

@Controller({ path: "age-verification-cms", version: Constants.API_VERSION_1 })

export class AgeVerificationCmsController {
    constructor(private readonly service: AgeVerificationCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "logo", maxCount: 1 },
          { name: "backgroundImage", maxCount: 1 }
      ]
    ))
    updateOrCreateData(
      @Body() dto: UpdateAgeVerificationCmsDto,
      @UploadedFiles() files: {
          logo: UploadedMulterFileI,
          backgroundImage: UploadedMulterFileI
      }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
