import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { ArticlePageCmsRepository } from "./article-page-cms.repository";
import { UpdateArticlePageCmsDto } from "./dto/update-article-page-cms.dto";
import { ArticlePageCms } from "./entities/article-page-cms.entity";

@Injectable()
export class ArticlePageCmsService {
    constructor(
      @InjectRepository(ArticlePageCmsRepository)
      private readonly repository: ArticlePageCmsRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateArticlePageCmsDto,
      files: {
          bannerImage: UploadedMulterFileI
      }
    ): Promise<ArticlePageCms | Error> {
        if (files && files.bannerImage) {
            const bannerImage: any = await this.doSpaceService.uploadFile(files.bannerImage[0], "ArticlePageCMS/");
            dto.bannerImage = bannerImage;
        }

        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ArticlePageCms[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}