import { EntityRepository, Repository } from "typeorm";
import { UpdateCareerPageCmsDto } from "./dto/update-career-page-cms.dto";
import { CareerPageCms } from "./entities/career-page-cms.entity";

@EntityRepository(CareerPageCms)
export class CareerPageCmsRepository extends Repository<CareerPageCms> {

    async createEntity(dto: UpdateCareerPageCmsDto): Promise<CareerPageCms | Error> {
        try {
            const entity = this.create({
                pageTitle: dto.pageTitle,
                departmentPageTitle: dto.departmentPageTitle,
                modalTitle: dto.modalTitle,
                modalSubTitle: dto.modalSubTitle,
                modalDescription: dto.modalDescription,
                modalButtonText: dto.modalButtonText
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async updateEntity(dto: UpdateCareerPageCmsDto, id: string): Promise<CareerPageCms | Error> {
        try {
            await this.update(id, {
                pageTitle: dto.pageTitle,
                departmentPageTitle: dto.departmentPageTitle,
                modalTitle: dto.modalTitle,
                modalSubTitle: dto.modalSubTitle,
                modalDescription: dto.modalDescription,
                modalButtonText: dto.modalButtonText
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findAll(): Promise<CareerPageCms[] | Error> {
        try {
            return await this.find({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }
}