import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateStoreDto } from "./dto/create-store.dto";
import { UpdateStoreDto } from "./dto/update-store.dto";
import { Store } from "./entities/store.entity";

@EntityRepository(Store)
export class StoreRepository extends Repository<Store> {
    async createEntity(dto: CreateStoreDto): Promise<Store | Error> {
        try {
            const {
                name,
                address,
                time,
                contactNumber
            } = dto;
            const entity = this.create({
                name,
                address,
                time,
                contactNumber
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<Store | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateStoreDto): Promise<Store | Error> {
        try {
            await this.update(id, {
                name: dto.name,
                address: dto.address,
                time: dto.time,
                contactNumber: dto.contactNumber
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<Store[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(Store)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}